@@ -1,28 +1,11 @@
-package Algorithm::CheckDigits::M10_002;
+package Algorithm::CheckDigits::M10_004;
 
 use 5.006;
 use strict;
 use warnings;
 use integer;
 
-require Exporter;
-
-our @ISA = qw(Exporter Algorithm::CheckDigits);
-
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# This allows declaration	use CheckDigits ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw(
-	
-) ] );
-
-our @EXPORT_OK = ( 'new', @{ $EXPORT_TAGS{'all'} } );
-
-our @EXPORT = ();
+our @ISA = qw(Algorithm::CheckDigits);
 
 sub new {
 	my $proto = shift;
@@ -73,10 +56,9 @@ sub _compute_checkdigit {
 		my @digits = split(//,$number);
 		my $even = 1;
 		my $sum  = 0;
-		for (my $i = $#digits; $i >= 0; $i--) {
+		for (my $i = $#digits;$i >= 0;$i--) {
 			if ($even) {
-				my $tmp = 2 * $digits[$i];
-				$sum += $tmp / 10 + $tmp % 10;
+				$sum += 3 * $digits[$i];
 			} else {
 				$sum += $digits[$i];
 			}
@@ -94,27 +76,26 @@ __END__
 
 =head1 NAME
 
-CheckDigits::M10_002 - compute check digits for CINS (US), SIREN (FR),
-SIRET (FR)
+CheckDigits::M10_004 - compute check digits for 2aus5, EAN, ILN, NVE
 
 =head1 SYNOPSIS
 
-  use CheckDigits;
+  use Algorithm::CheckDigits;
 
-  $siret = CheckDigits('siret');
+  $ean = CheckDigits('ean');
 
-  if ($siret->is_valid('73282932000074')) {
+  if ($ean->is_valid('7622200004607')) {
 	# do something
   }
 
-  $cn = $siret->complete('7328293200007');
-  # $cn = '73282932000074'
+  $cn = $ean->complete('762220000460');
+  # $cn = '7622200004607'
 
-  $cd = $siret->checkdigit('73282932000074');
-  # $cd = '4'
+  $cd = $ean->checkdigit('7622200004607');
+  # $cd = '7'
 
-  $bn = $siret->basenumber('73282932000074');
-  # $bn = '7328293200007'
+  $bn = $ean->basenumber('7622200004607');
+  # $bn = '762220000460'
   
 =head1 DESCRIPTION
 
@@ -124,11 +105,12 @@ SIRET (FR)
 
 =item 1
 
-Beginning right all numbers are weighted alternatively 1 and 2.
+Beginning right all numbers are weighted alternatively 1 and 3 (that
+is the check digit is weighted 1).
 
 =item 2
 
-The total of the digits of all products is computed.
+The sum of all products is computed.
 
 =item 3
 
@@ -136,11 +118,13 @@ The sum of step 3 ist taken modulo 10.
 
 =item 4
 
-The check digit is the difference between 10 and the number from step
-3 taken modulo 10.
+The check digit is the difference between 10 and the number from step 3.
 
 =back
 
+To validate the total of the digits of all numbers inclusive check
+digit taken modulo 10 must be 0.
+
 =head2 METHODS
 
 =over 4
@@ -189,6 +173,5 @@ Mathias Weidner, E<lt>mathias@weidner.in-bad-schmiedeberg.deE<gt>
 L<perl>,
 L<CheckDigits>,
 F<www.pruefziffernberechnung.de>.
-F<www.dsi.cnrs.fr/bureau_qualite/admindonnees/documents/siren.pdf>
 
 =cut
